MethodChannelCrossmintDeviceSigner class

Inheritance

Properties

hashCode int
The hash code for this object.
no setterinherited
methodChannel MethodChannel
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

deleteKey(String address) Future<void>
override
deletePendingKey(String publicKeyBase64) Future<void>
override
generateKey({String? address}) Future<String>
override
getDeviceName() Future<String?>
override
getKey(String address) Future<String?>
override
hasKey(String publicKeyBase64) Future<bool>
override
isAvailable() Future<bool>
override
mapAddressToKey(String address, String publicKeyBase64) Future<void>
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
signMessage({required String address, required String message}) Future<Map<String, Object?>>
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited