CrossmintDeviceSignerPlatform class abstract
- Inheritance
-
- Object
- PlatformInterface
- CrossmintDeviceSignerPlatform
- Implementers
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
deleteKey(
String address) → Future< void> -
deletePendingKey(
String publicKeyBase64) → Future< void> -
generateKey(
{String? address}) → Future< String> -
getDeviceName(
) → Future< String?> -
getKey(
String address) → Future< String?> -
hasKey(
String publicKeyBase64) → Future< bool> -
isAvailable(
) → Future< bool> -
mapAddressToKey(
String address, String publicKeyBase64) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
signMessage(
{required String address, required String message}) → Future< Map< String, Object?> > -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- instance ↔ CrossmintDeviceSignerPlatform
-
getter/setter pair